STANNIX Community


Manual: lsblk

LSBLK(8)					    System Administration					    LSBLK(8)

NAME
       lsblk - list block devices

SYNOPSIS
       lsblk [options] [device...]

DESCRIPTION
       lsblk lists information about all available or the specified block devices. The lsblk command reads the sysfs
       filesystem and udev db to gather information. If the udev db is not available or lsblk is compiled without udev
       support, then it tries to read LABELs, UUIDs and filesystem types from the block device. In this case root
       permissions are necessary.

       By default, the command prints all block devices (except RAM disks) in a tree-like format. The same device can be
       repeated in the tree if it relates to other devices. The --merge option is recommended for more complicated setups to
       gather groups of devices and describe complex N:M relationships.

       The tree-like output (or children[] array in the JSON output) is enabled only if NAME column it present in the output
       or when --tree command line option is used. See also --nodeps and --list to control the tree formatting.

       The default output, as well as the default output from options like --fs and --topology, is subject to change. So
       whenever possible, you should avoid using default outputs in your scripts. Always explicitly define expected columns
       by using --output columns-list and --list in environments where a stable output is required.

       Use lsblk --list-columns to get a list of all available columns.

       Note that lsblk might be executed in time when udev does not have all information about recently added or modified
       devices yet. In this case it is recommended to use udevadm settle before lsblk to synchronize with udev.

       The relationship between block devices and filesystems is not always one-to-one. The filesystem may use more block
       devices, or the same filesystem may be accessible by more paths. This is the reason why lsblk provides MOUNTPOINT and
       MOUNTPOINTS (pl.) columns. The column MOUNTPOINT displays only one mount point (usually the last mounted instance of
       the filesystem), and the column MOUNTPOINTS displays by multi-line cell all mount points associated with the device.

OPTIONS
       -A, --noempty
	   Don’t print empty devices.

       -a, --all
	   Disable all built-in filters and list all empty devices and RAM disk devices too.

       -b, --bytes
	   Print the sizes in bytes rather than in a human-readable format.

	   By default, the unit, sizes are expressed in, is byte, and unit prefixes are in power of 2^10 (1024).
	   Abbreviations of symbols are exhibited truncated in order to reach a better readability, by exhibiting alone the
	   first letter of them; examples: "1 KiB" and "1 MiB" are respectively exhibited as "1 K" and "1 M", then omitting
	   on purpose the mention "iB", which is part of these abbreviations.

       -H, --list-columns
	   List the available columns, use with --json or --raw to get output in machine-readable format.

       -D, --discard
	   Print information about the discarding capabilities (TRIM, UNMAP) for each device.

       -d, --nodeps
	   Do not print holder devices or slaves. For example, lsblk --nodeps /dev/sda prints information about the sda
	   device only.

       -E, --dedup column
	   Use column as a de-duplication key to de-duplicate output tree. If the key is not available for the device, or
	   the device is a partition and parental whole-disk device provides the same key than the device is always printed.

	   The usual use case is to de-duplicate output on system multi-path devices, for example by -E WWN.

       -e, --exclude list
	   Exclude the devices specified by the comma-separated list of major device numbers. Note that RAM disks (major=1)
	   are excluded by default if --all is not specified. The filter is applied to the top-level devices only. This may
	   be confusing for --list output format where hierarchy of the devices is not obvious.

       -f, --fs
	   Output info about filesystems. This option is equivalent to -o
	   NAME,FSTYPE,FSVER,LABEL,UUID,FSAVAIL,FSUSE%,MOUNTPOINTS. The authoritative information about filesystems and
	   raids is provided by the blkid(8) command.

       --hyperlink[=mode]
	   Print mountpoint paths as terminal hyperlinks. The mode can be set to "always", "never", or "auto". The optional
	   argument when can be set to "auto", "never", or "always". If the when argument is omitted, it will default to
	   "auto". The "auto" setting means that hyperlinks will only be used if the output is on a terminal.

       -I, --include list
	   Include devices specified by the comma-separated list of major device numbers. The filter is applied to the
	   top-level devices only. This may be confusing for --list output format where hierarchy of the devices is not
	   obvious.

       -i, --ascii
	   Use ASCII characters for tree formatting.

       -J, --json
	   Use JSON output format. It’s strongly recommended to use --output and also --tree if necessary. Note that
	   children[] is used only if NAME column or --tree is used.

       -l, --list
	   Produce output in the form of a list. The output does not provide information about relationships between devices
	   and since version 2.34 every device is printed only once if --pairs or --raw not specified (the parsable outputs
	   are maintained in backwardly compatible way).

       -M, --merge
	   Group parents of sub-trees to provide more readable output for RAIDs and Multi-path devices. The tree-like output
	   is required.

       -m, --perms
	   Output info about device owner, group and mode. This option is equivalent to -o NAME,SIZE,OWNER,GROUP,MODE.

       -N, --nvme
	   Output info about NVMe devices only.

       -v, --virtio
	   Output info about virtio devices only.

       -n, --noheadings
	   Do not print a header line.

       -o, --output list
	   Specify which output columns to print. Use --list-columns to get a list of all supported columns. The columns may
	   affect tree-like output. The default is to use tree for the column 'NAME' (see also --tree).

	   The default list of columns may be extended if list is specified in the format +list (e.g., lsblk -o +UUID).

       -O, --output-all
	   Output all available columns.

       -P, --pairs
	   Produce output in the form of key="value" pairs. The output lines are still ordered by dependencies. All
	   potentially unsafe value characters are hex-escaped (\x). See also option --shell.

       -p, --paths
	   Print full device paths.

       -Q, --filter expr
	   Print only the devices that meet the conditions specified by the expr. The filter is assessed prior to lsblk
	   collecting data for all output columns. Only the necessary data for the lazy evaluation of the expression is
	   retrieved from the system. This approach can enhance performance when compared to post-filtering, as commonly
	   done by tools such as grep(1).

	   This feature is EXPERIMENTAL. See also scols-filter(5). For example exclude sda  and sdb, but print everything
	   else ('!~' is a negative regular expression matching operator):

	      lsblk --filter 'NAME !~ "sd[ab]"'

       --highlight expr
	   Colorize lines matching the expression. This feature is EXPERIMENTAL. See also scols-filter(5).

       --ct name [: param [: function ]]
	   Define a custom counter. The counters are printed after the standard output. The name is the custom name of the
	   counter, the optional param is the name of the column to be used for the counter, and the optional function
	   specifies the aggregation function, supported functions are: count, min, max, or sum. The default is count.

	   If the param is not specified, then the counter counts the number of lines. This feature is EXPERIMENTAL. See
	   also --ct-filter.

	   For example, --ct MyCounter:SIZE:sum will count the summary for SIZE from all lines; and to count the number of
	   SATA disks, it is possible to use:

	      lsblk --ct-filter 'TYPE=="disk" && TRAN=="sata"' --ct "Number of SATA devices"

       --ct-filter expr
	   Define a restriction for the next counter. This feature is EXPERIMENTAL. See also --ct and scols-filter(5). For
	   example, aggregate sizes by device type:

	      lsblk --ct-filter 'TYPE=="part"' --ct Partitions:SIZE:sum \
		    --ct-filter 'TYPE=="disk"' --ct WholeDisks:SIZE:sum

       -r, --raw
	   Produce output in raw format. The output lines are still ordered by dependencies. All potentially unsafe
	   characters are hex-escaped (\x) in the NAME, KNAME, LABEL, PARTLABEL and MOUNTPOINT columns.

       -S, --scsi
	   Output info about SCSI devices only. All partitions, slaves and holder devices are ignored.

       -s, --inverse
	   Print dependencies in inverse order. If the --list output is requested then the lines are still ordered by
	   dependencies.

       -T, --tree[=column]
	   Force tree-like output format. If column is specified, then a tree is printed in the column. The default is NAME
	   column.

       -t, --topology
	   Output info about block-device topology. This option is equivalent to

	   -o NAME,ALIGNMENT,MIN-IO,OPT-IO,PHY-SEC,LOG-SEC,ROTA,SCHED,RQ-SIZE,RA,WSAME.

       -w, --width number
	   Specifies output width as a number of characters. The default is the number of the terminal columns, and if not
	   executed on a terminal, then output width is not restricted at all by default. This option also forces lsblk to
	   assume that terminal control characters and unsafe characters are not allowed. The expected use-case is for
	   example when lsblk is used by the watch(1) command.

       -x, --sort column
	   Sort output lines by column. This option enables --list output format by default. It is possible to use the
	   option --tree to force tree-like output and than the tree branches are sorted by the column.

       -y, --shell
	   The column name will be modified to contain only characters allowed for shell variable identifiers, for example,
	   MIN_IO and FSUSE_PCT instead of MIN-IO and FSUSE%. This is usable, for example, with --pairs. Note that this
	   feature has been automatically enabled for --pairs in version 2.37, but due to compatibility issues, now it’s
	   necessary to request this behavior by --shell.

       -z, --zoned
	   Print the zone related information for each device.

       --sysroot directory
	   Gather data for a Linux instance other than the instance from which the lsblk command is issued. The specified
	   directory is the system root of the Linux instance to be inspected. The real device nodes in the target directory
	   can be replaced by text files with udev attributes.

       --properties-by list
	   This option specifies the methods used by lsblk to gather information about filesystems and partition tables. The
	   list is a comma-separated list of method names. The default setting is "file,udev,blkid". The supported methods
	   are:

	   udev
	       Reads data from udev DB. If unsuccessful, it continues to the next probing method.

	   blkid
	       Reads data directly from the device using libblkid. If unsuccessful, it continues to the next probing method.

	   file
	       Reads data from a file. This method is only used if the --sysroot option is specified. This method always
	       stops probing if used.

	   none
	       Does not probe. This method always stops probing.

       -h, --help
	   Display help text and exit.

       -V, --version
	   Display version and exit.

EXIT STATUS
       0
	   success

       1
	   failure

       32
	   none of specified devices found

       64
	   some specified devices found, some not found

ENVIRONMENT
       LSBLK_DEBUG=all
	   enables lsblk debug output.

       LIBBLKID_DEBUG=all
	   enables libblkid debug output.

       LIBMOUNT_DEBUG=all
	   enables libmount debug output.

       LIBSMARTCOLS_DEBUG=all
	   enables libsmartcols debug output.

       LIBSMARTCOLS_DEBUG_PADDING=on
	   use visible padding characters.

NOTES
       For partitions, some information (e.g., queue attributes) is inherited from the parent device.

       The lsblk command needs to be able to look up each block device by major:minor numbers, which is done by using
       /sys/dev/block. This sysfs block directory appeared in kernel 2.6.27 (October 2008). In case of problems with a new
       enough kernel, check that CONFIG_SYSFS was enabled at the time of the kernel build.

AUTHORS
       Milan Broz , Karel Zak 

SEE ALSO
       blkid(8), findmnt(8) ls(1), scols-filter(5)

REPORTING BUGS
       For bug reports, use the issue tracker .

AVAILABILITY
       The lsblk command is part of the util-linux package which can be downloaded from Linux Kernel Archive
       .

util-linux 2.41.3					 2025-12-15						    LSBLK(8)